**************************
Python package description
**************************

The python package description gives a general description of the code itself. It describes the package structure (modules and classes, with their functions and variables).

Contents:

.. toctree::
   :maxdepth: 2

   energySystemModelDoc
   componentsDoc
   expansionModulesDoc
   outputManagerDoc